#' trim white spaces from a string
#'
#' This trims all white spaces from specified sides of a string.
#' @param x string or vector of strings to trim
#' @param what what to trim (interpreted as regex): \code{\\s} or
#' \code{[[:space:]]} is all white
#' space, could use ' ' for just plain spaces.
#' @param side One of 'both','left','right': which side(s) to trim.
#' @param perl boolean, whether the \code{what} regex is perl or not.
#' @return x trimmed.
#'
#' @examples
#' x <- '   a   '
#' trim(x,side='left')  # 'a   '
#' trim(x,side='right') # '   a'
#' trim(x)              # 'a'
#' 
#' y <- 'One line\nTwo lines\n\n  '
#' trim(y)              # 'One line\nTwo lines'
#' trim(y,what=' ')     # 'One line\nTwo lines\n\n' (trimmed just space)
#' @export
trim <- function(x,side=c('both','left','right'),what='[[:space:]]',perl=FALSE)
{
    side <- match.arg(side)
    # left trim
    if ( side != 'right' )
        x <- sub(sprintf('^%s+',what),'',x,perl=perl)
    # right trim
    if ( side != 'left' )
        x <- sub(sprintf('%s+$',what),'',x,perl=perl)
    return( x )
}

